@@ -3,7 +3,8 @@ import uuid
 
 ROOT_PATH = pathlib.Path(__file__).parent.resolve()
 
-_sql_lite_file = ROOT_PATH.joinpath('db').resolve()
+ROOT_PATH.joinpath('db').mkdir(exist_ok=True)
+_sql_lite_file = ROOT_PATH.joinpath('db').joinpath('sqlite.db').resolve()
 
 
 class FlaskConfig:
@@ -11,4 +12,3 @@ class FlaskConfig:
     SQLALCHEMY_DATABASE_URI = 'sqlite:///{}'.format(_sql_lite_file)
     SQLALCHEMY_TRACK_MODIFICATIONS = True
     SECRET_KEY = uuid.uuid4().hex
-
